@@ -190,7 +190,7 @@ func (is *imageStream) GetImageOfImageStream(ctx context.Context, dgst digest.Di
 }
 
 func (is *imageStream) GetSecrets() ([]corev1.Secret, *rerrors.Error) {
-	secrets, err := is.registryOSClient.ImageStreamSecrets(is.namespace).Secrets(is.name, metav1.GetOptions{})
+	secrets, err := is.registryOSClient.ImageStreamSecrets(is.namespace).Secrets(context.TODO(), is.name, metav1.GetOptions{})
 	if err != nil {
 		return nil, rerrors.NewError(
 			ErrImageStreamUnknownErrorCode,
@@ -257,12 +257,14 @@ func (is *imageStream) localRegistry(ctx context.Context) ([]string, *rerrors.Er
 		localNames = append(localNames, local.Registry)
 	}
 
-	public, err := imageapi.ParseDockerImageReference(stream.Status.PublicDockerImageRepository)
-	if err != nil {
-		dcontext.GetLogger(ctx).Warnf("localRegistry: unable to parse publicDockerImageRepository %q", stream.Status.PublicDockerImageRepository)
-	}
-	if len(public.Registry) != 0 {
-		localNames = append(localNames, public.Registry)
+	if len(stream.Status.PublicDockerImageRepository) > 0 {
+		public, err := imageapi.ParseDockerImageReference(stream.Status.PublicDockerImageRepository)
+		if err != nil {
+			dcontext.GetLogger(ctx).Warnf("localRegistry: unable to parse publicDockerImageRepository %q", stream.Status.PublicDockerImageRepository)
+		}
+		if len(public.Registry) != 0 {
+			localNames = append(localNames, public.Registry)
+		}
 	}
 
 	return localNames, nil
@@ -317,7 +319,7 @@ func (is *imageStream) CreateImageStreamMapping(ctx context.Context, userClient
 		Tag:   tag,
 	}
 
-	_, err := is.registryOSClient.ImageStreamMappings(is.namespace).Create(&ism)
+	_, err := is.registryOSClient.ImageStreamMappings(is.namespace).Create(ctx, &ism, metav1.CreateOptions{})
 
 	if err == nil {
 		return nil
@@ -344,6 +346,14 @@ func (is *imageStream) CreateImageStreamMapping(ctx context.Context, userClient
 	status := statusErr.ErrStatus
 	isValidKind := false
 
+	if kerrors.IsNotFound(statusErr) && strings.ToLower(status.Details.Kind) == "namespaces" {
+		return rerrors.NewError(
+			ErrImageStreamForbiddenCode,
+			fmt.Sprintf("CreateImageStreamMapping: error creating %s ImageStreamMapping", is.Reference()),
+			err,
+		)
+	}
+
 	if status.Details != nil {
 		switch strings.ToLower(status.Details.Kind) {
 		case "imagestream", /*pre-1.2*/
@@ -363,7 +373,7 @@ func (is *imageStream) CreateImageStreamMapping(ctx context.Context, userClient
 	stream := &imageapiv1.ImageStream{}
 	stream.Name = is.name
 
-	_, err = userClient.ImageStreams(is.namespace).Create(stream)
+	_, err = userClient.ImageStreams(is.namespace).Create(ctx, stream, metav1.CreateOptions{})
 
 	switch {
 	case kerrors.IsAlreadyExists(err), kerrors.IsConflict(err):
@@ -386,7 +396,7 @@ func (is *imageStream) CreateImageStreamMapping(ctx context.Context, userClient
 	is.imageStreamGetter.cacheImageStream(stream)
 
 	// try to create the ISM again
-	_, err = is.registryOSClient.ImageStreamMappings(is.namespace).Create(&ism)
+	_, err = is.registryOSClient.ImageStreamMappings(is.namespace).Create(ctx, &ism, metav1.CreateOptions{})
 
 	if err == nil {
 		return nil
@@ -418,7 +428,7 @@ func (is *imageStream) GetLimitRangeList(ctx context.Context, cache ProjectObjec
 
 	dcontext.GetLogger(ctx).Debugf("listing limit ranges in namespace %s", is.namespace)
 
-	lrs, err := is.registryOSClient.LimitRanges(is.namespace).List(metav1.ListOptions{})
+	lrs, err := is.registryOSClient.LimitRanges(is.namespace).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return nil, rerrors.NewError(
 			ErrImageStreamUnknownErrorCode,
